==> chaosmesh-model-6.9.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/FailKernRequestFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FailKernRequestFluent<A extends FailKernRequestFluent<A>> extends BaseFluent<A>{
  public FailKernRequestFluent() {
  }
  
  public FailKernRequestFluent(FailKernRequest instance) {
    this.copyInstance(instance);
  }
  private ArrayList<FrameBuilder> callchain = new ArrayList<FrameBuilder>();
  private Integer failtype;
  private List<String> headers = new ArrayList<String>();
  private Integer probability;
  private Integer times;
  
  protected void copyInstance(FailKernRequest instance) {
    instance = (instance != null ? instance : new FailKernRequest());
    if (instance != null) {
          this.withCallchain(instance.getCallchain());
          this.withFailtype(instance.getFailtype());
          this.withHeaders(instance.getHeaders());
          this.withProbability(instance.getProbability());
          this.withTimes(instance.getTimes());
          this.withCallchain(instance.getCallchain());
          this.withFailtype(instance.getFailtype());
          this.withHeaders(instance.getHeaders());
          this.withProbability(instance.getProbability());
          this.withTimes(instance.getTimes());
        }
  }
  
  public A addToCallchain(int index,Frame item) {
    if (this.callchain == null) {this.callchain = new ArrayList<FrameBuilder>();}
    FrameBuilder builder = new FrameBuilder(item);
    if (index < 0 || index >= callchain.size()) { _visitables.get("callchain").add(builder); callchain.add(builder); } else { _visitables.get("callchain").add(index, builder); callchain.add(index, builder);}
    return (A)this;
  }
  
  public A setToCallchain(int index,Frame item) {
    if (this.callchain == null) {this.callchain = new ArrayList<FrameBuilder>();}
    FrameBuilder builder = new FrameBuilder(item);
    if (index < 0 || index >= callchain.size()) { _visitables.get("callchain").add(builder); callchain.add(builder); } else { _visitables.get("callchain").set(index, builder); callchain.set(index, builder);}
    return (A)this;
  }
  
  public A addToCallchain(io.fabric8.chaosmesh.v1alpha1.Frame... items) {
    if (this.callchain == null) {this.callchain = new ArrayList<FrameBuilder>();}
    for (Frame item : items) {FrameBuilder builder = new FrameBuilder(item);_visitables.get("callchain").add(builder);this.callchain.add(builder);} return (A)this;
  }
  
  public A addAllToCallchain(Collection<Frame> items) {
    if (this.callchain == null) {this.callchain = new ArrayList<FrameBuilder>();}
    for (Frame item : items) {FrameBuilder builder = new FrameBuilder(item);_visitables.get("callchain").add(builder);this.callchain.add(builder);} return (A)this;
  }
  
  public A removeFromCallchain(io.fabric8.chaosmesh.v1alpha1.Frame... items) {
    if (this.callchain == null) return (A)this;
    for (Frame item : items) {FrameBuilder builder = new FrameBuilder(item);_visitables.get("callchain").remove(builder); this.callchain.remove(builder);} return (A)this;
  }
  
  public A removeAllFromCallchain(Collection<Frame> items) {
    if (this.callchain == null) return (A)this;
    for (Frame item : items) {FrameBuilder builder = new FrameBuilder(item);_visitables.get("callchain").remove(builder); this.callchain.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromCallchain(Predicate<FrameBuilder> predicate) {
    if (callchain == null) return (A) this;
    final Iterator<FrameBuilder> each = callchain.iterator();
    final List visitables = _visitables.get("callchain");
    while (each.hasNext()) {
      FrameBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<Frame> buildCallchain() {
    return this.callchain != null ? build(callchain) : null;
  }
  
  public Frame buildCallchain(int index) {
    return this.callchain.get(index).build();
  }
  
  public Frame buildFirstCallchain() {
    return this.callchain.get(0).build();
  }
  
  public Frame buildLastCallchain() {
    return this.callchain.get(callchain.size() - 1).build();
  }
  
  public Frame buildMatchingCallchain(Predicate<FrameBuilder> predicate) {
      for (FrameBuilder item : callchain) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingCallchain(Predicate<FrameBuilder> predicate) {
      for (FrameBuilder item : callchain) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withCallchain(List<Frame> callchain) {
    if (this.callchain != null) {
      this._visitables.get("callchain").clear();
    }
    if (callchain != null) {
        this.callchain = new ArrayList();
        for (Frame item : callchain) {
          this.addToCallchain(item);
        }
    } else {
      this.callchain = null;
    }
    return (A) this;
  }
  
  public A withCallchain(io.fabric8.chaosmesh.v1alpha1.Frame... callchain) {
    if (this.callchain != null) {this.callchain.clear(); _visitables.remove("callchain"); }
    if (callchain != null) {for (Frame item :callchain){ this.addToCallchain(item);}} return (A) this;
  }
  
  public boolean hasCallchain() {
    return this.callchain != null && !this.callchain.isEmpty();
  }
  
  public A addNewCallchain(String funcname,String parameters,String predicate) {
    return (A)addToCallchain(new Frame(funcname, parameters, predicate));
  }
  
  public CallchainNested<A> addNewCallchain() {
    return new CallchainNested(-1, null);
  }
  
  public CallchainNested<A> addNewCallchainLike(Frame item) {
    return new CallchainNested(-1, item);
  }
  
  public CallchainNested<A> setNewCallchainLike(int index,Frame item) {
    return new CallchainNested(index, item);
  }
  
  public CallchainNested<A> editCallchain(int index) {
    if (callchain.size() <= index) throw new RuntimeException("Can't edit callchain. Index exceeds size.");
    return setNewCallchainLike(index, buildCallchain(index));
  }
  
  public CallchainNested<A> editFirstCallchain() {
    if (callchain.size() == 0) throw new RuntimeException("Can't edit first callchain. The list is empty.");
    return setNewCallchainLike(0, buildCallchain(0));
  }
  
  public CallchainNested<A> editLastCallchain() {
    int index = callchain.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last callchain. The list is empty.");
    return setNewCallchainLike(index, buildCallchain(index));
  }
  
  public CallchainNested<A> editMatchingCallchain(Predicate<FrameBuilder> predicate) {
    int index = -1;
    for (int i=0;i<callchain.size();i++) { 
    if (predicate.test(callchain.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching callchain. No match found.");
    return setNewCallchainLike(index, buildCallchain(index));
  }
  
  public Integer getFailtype() {
    return this.failtype;
  }
  
  public A withFailtype(Integer failtype) {
    this.failtype = failtype;
    return (A) this;
  }
  
  public boolean hasFailtype() {
    return this.failtype != null;
  }
  
  public A addToHeaders(int index,String item) {
    if (this.headers == null) {this.headers = new ArrayList<String>();}
    this.headers.add(index, item);
    return (A)this;
  }
  
  public A setToHeaders(int index,String item) {
    if (this.headers == null) {this.headers = new ArrayList<String>();}
    this.headers.set(index, item); return (A)this;
  }
  
  public A addToHeaders(java.lang.String... items) {
    if (this.headers == null) {this.headers = new ArrayList<String>();}
    for (String item : items) {this.headers.add(item);} return (A)this;
  }
  
  public A addAllToHeaders(Collection<String> items) {
    if (this.headers == null) {this.headers = new ArrayList<String>();}
    for (String item : items) {this.headers.add(item);} return (A)this;
  }
  
  public A removeFromHeaders(java.lang.String... items) {
    if (this.headers == null) return (A)this;
    for (String item : items) { this.headers.remove(item);} return (A)this;
  }
  
  public A removeAllFromHeaders(Collection<String> items) {
    if (this.headers == null) return (A)this;
    for (String item : items) { this.headers.remove(item);} return (A)this;
  }
  
  public List<String> getHeaders() {
    return this.headers;
  }
  
  public String getHeader(int index) {
    return this.headers.get(index);
  }
  
  public String getFirstHeader() {
    return this.headers.get(0);
  }
  
  public String getLastHeader() {
    return this.headers.get(headers.size() - 1);
  }
  
  public String getMatchingHeader(Predicate<String> predicate) {
      for (String item : headers) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingHeader(Predicate<String> predicate) {
      for (String item : headers) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withHeaders(List<String> headers) {
    if (headers != null) {
        this.headers = new ArrayList();
        for (String item : headers) {
          this.addToHeaders(item);
        }
    } else {
      this.headers = null;
    }
    return (A) this;
  }
  
  public A withHeaders(java.lang.String... headers) {
    if (this.headers != null) {this.headers.clear(); _visitables.remove("headers"); }
    if (headers != null) {for (String item :headers){ this.addToHeaders(item);}} return (A) this;
  }
  
  public boolean hasHeaders() {
    return this.headers != null && !this.headers.isEmpty();
  }
  
  public Integer getProbability() {
    return this.probability;
  }
  
  public A withProbability(Integer probability) {
    this.probability = probability;
    return (A) this;
  }
  
  public boolean hasProbability() {
    return this.probability != null;
  }
  
  public Integer getTimes() {
    return this.times;
  }
  
  public A withTimes(Integer times) {
    this.times = times;
    return (A) this;
  }
  
  public boolean hasTimes() {
    return this.times != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FailKernRequestFluent that = (FailKernRequestFluent) o;
    if (!java.util.Objects.equals(callchain, that.callchain)) return false;
    if (!java.util.Objects.equals(failtype, that.failtype)) return false;
    if (!java.util.Objects.equals(headers, that.headers)) return false;
    if (!java.util.Objects.equals(probability, that.probability)) return false;
    if (!java.util.Objects.equals(times, that.times)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(callchain,  failtype,  headers,  probability,  times,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (callchain != null && !callchain.isEmpty()) { sb.append("callchain:"); sb.append(callchain + ","); }
    if (failtype != null) { sb.append("failtype:"); sb.append(failtype + ","); }
    if (headers != null && !headers.isEmpty()) { sb.append("headers:"); sb.append(headers + ","); }
    if (probability != null) { sb.append("probability:"); sb.append(probability + ","); }
    if (times != null) { sb.append("times:"); sb.append(times); }
    sb.append("}");
    return sb.toString();
  }
  public class CallchainNested<N> extends FrameFluent<CallchainNested<N>> implements Nested<N>{
    CallchainNested(int index,Frame item) {
      this.index = index;
      this.builder = new FrameBuilder(this, item);
    }
    FrameBuilder builder;
    int index;
    
    public N and() {
      return (N) FailKernRequestFluent.this.setToCallchain(index,builder.build());
    }
    
    public N endCallchain() {
      return and();
    }
    
  
  }

}

==> chaosmesh-model-7.4.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/FailKernRequestFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FailKernRequestFluent<A extends FailKernRequestFluent<A>> extends BaseFluent<A>{
  public FailKernRequestFluent() {
  }
  
  public FailKernRequestFluent(FailKernRequest instance) {
    this.copyInstance(instance);
  }
  private ArrayList<FrameBuilder> callchain = new ArrayList<FrameBuilder>();
  private Integer failtype;
  private List<String> headers = new ArrayList<String>();
  private Long probability;
  private Long times;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(FailKernRequest instance) {
    instance = (instance != null ? instance : new FailKernRequest());
    if (instance != null) {
          this.withCallchain(instance.getCallchain());
          this.withFailtype(instance.getFailtype());
          this.withHeaders(instance.getHeaders());
          this.withProbability(instance.getProbability());
          this.withTimes(instance.getTimes());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public A addToCallchain(int index,Frame item) {
    if (this.callchain == null) {this.callchain = new ArrayList<FrameBuilder>();}
    FrameBuilder builder = new FrameBuilder(item);
    if (index < 0 || index >= callchain.size()) {
        _visitables.get("callchain").add(builder);
        callchain.add(builder);
    } else {
        _visitables.get("callchain").add(builder);
        callchain.add(index, builder);
    }
    return (A)this;
  }
  
  public A setToCallchain(int index,Frame item) {
    if (this.callchain == null) {this.callchain = new ArrayList<FrameBuilder>();}
    FrameBuilder builder = new FrameBuilder(item);
    if (index < 0 || index >= callchain.size()) {
        _visitables.get("callchain").add(builder);
        callchain.add(builder);
    } else {
        _visitables.get("callchain").add(builder);
        callchain.set(index, builder);
    }
    return (A)this;
  }
  
  public A addToCallchain(io.fabric8.chaosmesh.v1alpha1.Frame... items) {
    if (this.callchain == null) {this.callchain = new ArrayList<FrameBuilder>();}
    for (Frame item : items) {FrameBuilder builder = new FrameBuilder(item);_visitables.get("callchain").add(builder);this.callchain.add(builder);} return (A)this;
  }
  
  public A addAllToCallchain(Collection<Frame> items) {
    if (this.callchain == null) {this.callchain = new ArrayList<FrameBuilder>();}
    for (Frame item : items) {FrameBuilder builder = new FrameBuilder(item);_visitables.get("callchain").add(builder);this.callchain.add(builder);} return (A)this;
  }
  
  public A removeFromCallchain(io.fabric8.chaosmesh.v1alpha1.Frame... items) {
    if (this.callchain == null) return (A)this;
    for (Frame item : items) {FrameBuilder builder = new FrameBuilder(item);_visitables.get("callchain").remove(builder); this.callchain.remove(builder);} return (A)this;
  }
  
  public A removeAllFromCallchain(Collection<Frame> items) {
    if (this.callchain == null) return (A)this;
    for (Frame item : items) {FrameBuilder builder = new FrameBuilder(item);_visitables.get("callchain").remove(builder); this.callchain.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromCallchain(Predicate<FrameBuilder> predicate) {
    if (callchain == null) return (A) this;
    final Iterator<FrameBuilder> each = callchain.iterator();
    final List visitables = _visitables.get("callchain");
    while (each.hasNext()) {
      FrameBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<Frame> buildCallchain() {
    return this.callchain != null ? build(callchain) : null;
  }
  
  public Frame buildCallchain(int index) {
    return this.callchain.get(index).build();
  }
  
  public Frame buildFirstCallchain() {
    return this.callchain.get(0).build();
  }
  
  public Frame buildLastCallchain() {
    return this.callchain.get(callchain.size() - 1).build();
  }
  
  public Frame buildMatchingCallchain(Predicate<FrameBuilder> predicate) {
      for (FrameBuilder item : callchain) {
        if (predicate.test(item)) {
          return item.build();
        }
      }
      return null;
  }
  
  public boolean hasMatchingCallchain(Predicate<FrameBuilder> predicate) {
      for (FrameBuilder item : callchain) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withCallchain(List<Frame> callchain) {
    if (this.callchain != null) {
      this._visitables.get("callchain").clear();
    }
    if (callchain != null) {
        this.callchain = new ArrayList();
        for (Frame item : callchain) {
          this.addToCallchain(item);
        }
    } else {
      this.callchain = null;
    }
    return (A) this;
  }
  
  public A withCallchain(io.fabric8.chaosmesh.v1alpha1.Frame... callchain) {
    if (this.callchain != null) {
        this.callchain.clear();
        _visitables.remove("callchain");
    }
    if (callchain != null) {
      for (Frame item : callchain) {
        this.addToCallchain(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasCallchain() {
    return this.callchain != null && !this.callchain.isEmpty();
  }
  
  public A addNewCallchain(String funcname,String parameters,String predicate) {
    return (A)addToCallchain(new Frame(funcname, parameters, predicate));
  }
  
  public CallchainNested<A> addNewCallchain() {
    return new CallchainNested(-1, null);
  }
  
  public CallchainNested<A> addNewCallchainLike(Frame item) {
    return new CallchainNested(-1, item);
  }
  
  public CallchainNested<A> setNewCallchainLike(int index,Frame item) {
    return new CallchainNested(index, item);
  }
  
  public CallchainNested<A> editCallchain(int index) {
    if (callchain.size() <= index) throw new RuntimeException("Can't edit callchain. Index exceeds size.");
    return setNewCallchainLike(index, buildCallchain(index));
  }
  
  public CallchainNested<A> editFirstCallchain() {
    if (callchain.size() == 0) throw new RuntimeException("Can't edit first callchain. The list is empty.");
    return setNewCallchainLike(0, buildCallchain(0));
  }
  
  public CallchainNested<A> editLastCallchain() {
    int index = callchain.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last callchain. The list is empty.");
    return setNewCallchainLike(index, buildCallchain(index));
  }
  
  public CallchainNested<A> editMatchingCallchain(Predicate<FrameBuilder> predicate) {
    int index = -1;
    for (int i=0;i<callchain.size();i++) { 
    if (predicate.test(callchain.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching callchain. No match found.");
    return setNewCallchainLike(index, buildCallchain(index));
  }
  
  public Integer getFailtype() {
    return this.failtype;
  }
  
  public A withFailtype(Integer failtype) {
    this.failtype = failtype;
    return (A) this;
  }
  
  public boolean hasFailtype() {
    return this.failtype != null;
  }
  
  public A addToHeaders(int index,String item) {
    if (this.headers == null) {this.headers = new ArrayList<String>();}
    this.headers.add(index, item);
    return (A)this;
  }
  
  public A setToHeaders(int index,String item) {
    if (this.headers == null) {this.headers = new ArrayList<String>();}
    this.headers.set(index, item); return (A)this;
  }
  
  public A addToHeaders(java.lang.String... items) {
    if (this.headers == null) {this.headers = new ArrayList<String>();}
    for (String item : items) {this.headers.add(item);} return (A)this;
  }
  
  public A addAllToHeaders(Collection<String> items) {
    if (this.headers == null) {this.headers = new ArrayList<String>();}
    for (String item : items) {this.headers.add(item);} return (A)this;
  }
  
  public A removeFromHeaders(java.lang.String... items) {
    if (this.headers == null) return (A)this;
    for (String item : items) { this.headers.remove(item);} return (A)this;
  }
  
  public A removeAllFromHeaders(Collection<String> items) {
    if (this.headers == null) return (A)this;
    for (String item : items) { this.headers.remove(item);} return (A)this;
  }
  
  public List<String> getHeaders() {
    return this.headers;
  }
  
  public String getHeader(int index) {
    return this.headers.get(index);
  }
  
  public String getFirstHeader() {
    return this.headers.get(0);
  }
  
  public String getLastHeader() {
    return this.headers.get(headers.size() - 1);
  }
  
  public String getMatchingHeader(Predicate<String> predicate) {
      for (String item : headers) {
        if (predicate.test(item)) {
          return item;
        }
      }
      return null;
  }
  
  public boolean hasMatchingHeader(Predicate<String> predicate) {
      for (String item : headers) {
        if (predicate.test(item)) {
          return true;
        }
      }
      return false;
  }
  
  public A withHeaders(List<String> headers) {
    if (headers != null) {
        this.headers = new ArrayList();
        for (String item : headers) {
          this.addToHeaders(item);
        }
    } else {
      this.headers = null;
    }
    return (A) this;
  }
  
  public A withHeaders(java.lang.String... headers) {
    if (this.headers != null) {
        this.headers.clear();
        _visitables.remove("headers");
    }
    if (headers != null) {
      for (String item : headers) {
        this.addToHeaders(item);
      }
    }
    return (A) this;
  }
  
  public boolean hasHeaders() {
    return this.headers != null && !this.headers.isEmpty();
  }
  
  public Long getProbability() {
    return this.probability;
  }
  
  public A withProbability(Long probability) {
    this.probability = probability;
    return (A) this;
  }
  
  public boolean hasProbability() {
    return this.probability != null;
  }
  
  public Long getTimes() {
    return this.times;
  }
  
  public A withTimes(Long times) {
    this.times = times;
    return (A) this;
  }
  
  public boolean hasTimes() {
    return this.times != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FailKernRequestFluent that = (FailKernRequestFluent) o;
    if (!java.util.Objects.equals(callchain, that.callchain)) return false;
    if (!java.util.Objects.equals(failtype, that.failtype)) return false;
    if (!java.util.Objects.equals(headers, that.headers)) return false;
    if (!java.util.Objects.equals(probability, that.probability)) return false;
    if (!java.util.Objects.equals(times, that.times)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(callchain,  failtype,  headers,  probability,  times,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (callchain != null && !callchain.isEmpty()) { sb.append("callchain:"); sb.append(callchain + ","); }
    if (failtype != null) { sb.append("failtype:"); sb.append(failtype + ","); }
    if (headers != null && !headers.isEmpty()) { sb.append("headers:"); sb.append(headers + ","); }
    if (probability != null) { sb.append("probability:"); sb.append(probability + ","); }
    if (times != null) { sb.append("times:"); sb.append(times + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class CallchainNested<N> extends FrameFluent<CallchainNested<N>> implements Nested<N>{
    CallchainNested(int index,Frame item) {
      this.index = index;
      this.builder = new FrameBuilder(this, item);
    }
    FrameBuilder builder;
    int index;
    
    public N and() {
      return (N) FailKernRequestFluent.this.setToCallchain(index,builder.build());
    }
    
    public N endCallchain() {
      return and();
    }
    
  
  }

}
